@@ -6,17 +6,24 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
   ...,
 ### subject data frame, colName1=list(groupName1=pattern1, fun1, etc),
 ### colName2=list(etc), etc. First argument must be a data frame with
-### one or more character columns of subjects for matching. Each other
-### argument must be named using a column name of the subject data
-### frame, e.g. colName1, colName2. Each other argument value must be
-### a list that specifies the regex/conversion to use (in
-### string/function/list format as documented in capture_first_vec,
-### which is used on each named column), and possibly a
-### column-specific engine to use.
+### one or more character columns of subjects for matching. If the
+### first argument is a data table then it will be modified using
+### data.table::set (for memory efficiency, to avoid copying the whole
+### data table); otherwise the input data frame will be copied to a
+### new data table. Each other argument must be named using a column
+### name of the subject data frame, e.g. colName1, colName2. Each
+### other argument value must be a list that specifies the
+### regex/conversion to use (in string/function/list format as
+### documented in capture_first_vec, which is used on each named
+### column), and possibly a column-specific engine to use.
   nomatch.error=getOption("nc.nomatch.error", TRUE),
 ### if TRUE (default), stop with an error if any subject does not
 ### match; otherwise subjects that do not match are reported as
 ### missing/NA rows of the result.
+  existing.error=getOption("nc.existing.error", TRUE),
+### if TRUE (default to avoid data loss), stop with an error if any
+### capture groups have the same name as an existing column of
+### subject.
   engine=getOption("nc.engine", "PCRE")
 ### character string, one of PCRE, ICU, RE2. This engine will be used
 ### for each column, unless another engine is specified for that
@@ -24,35 +31,31 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
 ){
   all.arg.list <- list(...)
   subject <- all.arg.list[[1]]
-  if(!is.data.frame(subject)){
-    stop("subject must be a data.frame with character columns to match")
+  if(!is.data.table(subject)){
+    if(!is.data.frame(subject)){
+      stop("subject must be a data.frame with character columns to match")
+    }
+    subject <- as.data.table(subject)
   }
   col.pattern.list <- all.arg.list[-1]
   if(length(col.pattern.list)==0){
-    stop(
-      "no patterns specified in ...; ",
-      "must specify subjectColName=list(groupName=pattern, etc), etc")
+    stop(domain=NA, gettext("no patterns specified in ...; must specify subjectColName=list(groupName=pattern, etc), etc"))
   }
   valid.name <- names(col.pattern.list) %in% names(subject)
   invalid.vec <- names(col.pattern.list)[!valid.name]
   if(is.null(names(col.pattern.list)) || length(invalid.vec)){
-    stop("named args (", paste(invalid.vec, collapse=", "),
-         ") not found in subject column names (", paste(names(subject), collapse=", "),
-         "); each pattern in ... must be named using a column name of subject")
+    stop(domain=NA, gettextf("named args (%s) not found in subject column names (%s); each pattern in ... must be named using a column name of subject", paste(invalid.vec, collapse = ", "), paste(names(subject), collapse = ", ")))
   }
   if(names(all.arg.list)[[1]] != ""){
     stop("first argument (subject data.frame) should not be named")
   }
   name.tab <- table(names(col.pattern.list))
   if(any(bad <- 1 < name.tab)){
-    stop(
-      "each argument / subject column name should be unique, problems: ",
-      paste(names(name.tab)[bad], collapse=", "))
+    stop(domain=NA, gettextf("each argument / subject column name should be unique, problems: %s", paste(names(name.tab)[bad], collapse = ", ")))
   }
-  out <- data.table(subject)
   name.group.used <- FALSE
   for(col.name in names(col.pattern.list)){
-    subject.vec <- out[[col.name]]
+    subject.vec <- subject[[col.name]]
     col.arg.list <- c(list(subject.vec), col.pattern.list[[col.name]])
     maybe.rep <- c("engine", "nomatch.error")
     to.rep <- maybe.rep[!maybe.rep %in% names(col.arg.list)]
@@ -60,20 +63,15 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
     tryCatch({
       m <- do.call(capture_first_vec, col.arg.list)
     }, error=function(e){
-      stop("problem for subject column ", col.name, ": ", e)
+      stop(domain=NA, gettextf("problem for subject column %s: %s", col.name, e))
     })
-    new.bad <- names(m) %in% names(out)
-    if(any(new.bad)){
-      stop(
-        "capture group names (",
-        paste(names(m), collapse=", "),
-        ") must not conflict with existing column names (",
-        paste(names(out), collapse=", "),
-        ")")
+    new.bad <- names(m) %in% names(subject)
+    if(isTRUE(existing.error) && any(new.bad)){
+      stop(domain=NA, gettextf("capture group names (%s) must not conflict with existing column names (%s); fix by changing capture group names or use existing.error=FALSE to overwrite existing column names", paste(names(m), collapse = ", "), paste(names(subject), collapse = ", ")))
     }
-    out <- cbind(out, m, stringsAsFactors=FALSE)
+    set(subject, j=names(m), value=m)
   }
-  out
+  subject
 ### data.table with same number of rows as subject, with an additional
 ### column for each named capture group specified in ...
 }, ex=function(){
@@ -130,7 +128,7 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
   nc::capture_first_df(sacct.df, JobID=task.type.pattern)
 
   ## Match full JobID and Elapsed columns.
-  (task.df <- nc::capture_first_df(
+  nc::capture_first_df(
     sacct.df,
     JobID=list(
       job=int.pattern,
@@ -140,7 +138,14 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
       ":",
       minutes=int.pattern,
       ":",
-      seconds=int.pattern)))
-  str(task.df)
+      seconds=int.pattern))
+
+  ## If input is data table then it is modified for memory efficiency,
+  ## to avoid copying entire table.
+  sacct.DT <- data.table::as.data.table(sacct.df)
+  nc::capture_first_df(sacct.df, JobID=task.pattern)
+  sacct.df #not modified.
+  nc::capture_first_df(sacct.DT, JobID=task.pattern)
+  sacct.DT #modified!
 
 })
